==> web-midi-emitter-0.2.0.tgz: package/lib/index.js <==
"use strict";

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var events = require("events");

var WebMIDIEmitter = function (_events$EventEmitter) {
  _inherits(WebMIDIEmitter, _events$EventEmitter);

  function WebMIDIEmitter(access, deviceName) {
    _classCallCheck(this, WebMIDIEmitter);

    var _this = _possibleConstructorReturn(this, Object.getPrototypeOf(WebMIDIEmitter).call(this));

    _this.access = access;
    _this.deviceName = deviceName;

    _this._setupInputPort();
    _this._setupOutputPort();

    _this.access.addEventListener("statechange", function (e) {
      if (e.port.name === deviceName) {
        _this._setupInputPort();
        _this._setupOutputPort();
        _this.emit("statechange", e);
      }
    });
    return _this;
  }

  _createClass(WebMIDIEmitter, [{
    key: "write",
    value: function write(data) {
      if (this.output) {
        this.output.send(data);
      }
    }
  }, {
    key: "_setupInputPort",
    value: function _setupInputPort() {
      var _this2 = this;

      if (!this.input) {
        this.input = getPort(this.access.inputs, this.deviceName);
        if (this.input) {
          this.input.onmidimessage = function (e) {
            _this2.emit("data", e.data);
          };
        }
      }
      return this.input;
    }
  }, {
    key: "_setupOutputPort",
    value: function _setupOutputPort() {
      if (!this.output) {
        this.output = getPort(this.access.outputs, this.deviceName);
      }
      return this.output;
    }
  }]);

  return WebMIDIEmitter;
}(events.EventEmitter);

function getPort(map, deviceName) {
  return Array.from(map.values()).filter(function (device) {
    return device.name === deviceName;
  })[0] || null;
}

module.exports = WebMIDIEmitter;

==> web-midi-emitter-0.3.0.tgz: package/lib/index.js <==
"use strict";

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var events = require("events");

var WebMIDIEmitter = function (_events$EventEmitter) {
  _inherits(WebMIDIEmitter, _events$EventEmitter);

  function WebMIDIEmitter(access, deviceNameMatcher) {
    _classCallCheck(this, WebMIDIEmitter);

    var _this = _possibleConstructorReturn(this, Object.getPrototypeOf(WebMIDIEmitter).call(this));

    _this.access = access;
    _this.deviceName = "";
    _this._deviceNameMatcher = deviceNameMatcher;

    _this._setupInputPort();
    _this._setupOutputPort();

    _this.access.addEventListener("statechange", function (e) {
      if (e.port.name === _this.deviceName) {
        _this._setupInputPort();
        _this._setupOutputPort();
        _this.emit("statechange", e);
      }
    });
    return _this;
  }

  _createClass(WebMIDIEmitter, [{
    key: "write",
    value: function write(data) {
      if (this.output) {
        this.output.send(data);
      }
    }
  }, {
    key: "_setupInputPort",
    value: function _setupInputPort() {
      var _this2 = this;

      if (!this.input) {
        this.input = getPort(this.access.inputs, this._deviceNameMatcher);
        if (this.input) {
          this.deviceName = this.input.name;
          this.input.onmidimessage = function (e) {
            _this2.emit("data", e.data);
          };
        }
      }
      return this.input;
    }
  }, {
    key: "_setupOutputPort",
    value: function _setupOutputPort() {
      if (!this.output) {
        this.output = getPort(this.access.outputs, this._deviceNameMatcher);
        if (this.output) {
          this.deviceName = this.output.name;
        }
      }
      return this.output;
    }
  }]);

  return WebMIDIEmitter;
}(events.EventEmitter);

function getPort(map, deviceNameMatcher) {
  return Array.from(map.values()).filter(function (device) {
    return !!device.name.match(deviceNameMatcher);
  })[0] || null;
}

module.exports = WebMIDIEmitter;
